@@ -1,8 +1,8 @@
 /* gnome-stones - io.c
  *
- * Time-stamp: <1999/08/09 18:05:13 robert>
+ * Time-stamp: <2003-06-19 10:49:32 callum>
  *
- * Copyright (C) 1998 Carsten Schaar
+ * Copyright (C) 1998, 2003 Carsten Schaar
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,6 +18,12 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
+
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#include "status.h"
 #include "io.h"
 #include "cave.h"
 #include "game.h"
@@ -98,7 +104,7 @@ game_parse_object_section (GStonesGame *game)
      In this case, every object will be indexed by two or more
      characters (like in the xpm file format).  */
 
-  key_size= gnome_config_get_int_with_default ("General/Object Size",
+  key_size= gnome_config_get_int_with_default ("General/Object Size=1",
 					       &is_default);
   if (is_default)
     {
@@ -167,12 +173,18 @@ gstones_game_load (const gchar *name)
   
   gnome_config_push_prefix (game->config_prefix);
 
-  /* FIXME: Add check, if title is unset. */
-  game->title         = gnome_config_get_translated_string ("General/Title");
-  game->frame_rate    = gnome_config_get_float ("General/Frame rate=0.2")*1000;
+  game->title = gnome_config_get_translated_string_with_default ("General/Title",
+                                                                 NULL);
+  if (game->title == NULL) {
+    game_free (game);
+    gnome_config_pop_prefix ();
+    return NULL;
+  }
+  game->frame_rate    = gnome_config_get_float ("General/Frame rate=0.125")*1000;
   game->new_life_score= gnome_config_get_int    ("General/New life score=500");
   game->lives         = gnome_config_get_int    ("General/Lives=3");
   
+
   /* We now determine the plugins, that this game requires.  */
   {
     gchar *token;
@@ -321,9 +333,9 @@ gstones_cave_load (GStonesGame *game, const gchar *cavename)
 
   if ((cave->width > CAVE_MAX_WIDTH) || (cave->height > CAVE_MAX_HEIGHT))
     {
-      /* This cave is to big to be played with gnome-stones.  */
+      /* This cave is too big to be played with gnome-stones.  */
 
-      gstone_error (_("The cave you are trying to load it to big for this game."));
+      gstone_error (_("The cave you are trying to load is too big for this game."));
       
       gnome_config_pop_prefix ();
       cave_free (cave);
@@ -335,9 +347,18 @@ gstones_cave_load (GStonesGame *game, const gchar *cavename)
     {
       char *line;
       char  buffer[8];
+      gchar * error;
       sprintf (buffer, "Line%.2d", y);
-
+      
       line= gnome_config_get_string (buffer);
+      if (!line) {
+        error = g_strdup_printf (_("The cave is corrupted: %s is missing."), buffer);
+        gstone_error (error);
+        g_free (error);
+        gnome_config_pop_prefix ();
+        cave_free (cave);
+        return NULL;
+      }
       
       for (x= 1 ; x <= MIN (strlen (line), cave->width); x++)
 	{
