@@ -60,7 +60,7 @@
 const char *player_name;
 const char *opponent_name;
 
-char *game_server; 
+char *games_network_server_name; 
 static char *game_port;
 static pid_t server_pid = - 1;
 
@@ -330,7 +330,7 @@ network_connect (void)
 
   memset (&hints, 0, sizeof(hints));
   hints.ai_socktype = SOCK_STREAM;
-  x = getaddrinfo (game_server, game_port, &hints, &res);
+  x = getaddrinfo (games_network_server_name, game_port, &hints, &res);
   if (x) {
     network_set_status (netgame, DISCONNECTED, gai_strerror(x));
     return;
@@ -380,8 +380,8 @@ games_network_connect (const char *server, const char *id)
   player_name = id;
   games_network_start (); 
 
-  game_server = (char *)server;
-  if (!game_server) {
+  games_network_server_name = (char *)server;
+  if (!games_network_server_name) {
     network_set_status (netgame, DISCONNECTED, _("No game server defined"));
     return;
   }
@@ -402,7 +402,7 @@ games_network_connect (const char *server, const char *id)
 void 
 games_network_new (char *server, char *port, GtkWidget *parent_window)
 {
-  game_server = server;
+  games_network_server_name = server;
   game_port = port;
 
   network_game_dialog_show (parent_window);
